#include "AppClient.h"


#include <iostream>
using namespace refinitiv::ema::access;
using namespace refinitiv::ema::rdm;
using namespace std;


AppClient::AppClient() :	
	_tunnelStreamClient(0)	
{
}

AppClient::~AppClient()
{
}
void AppClient::setTunnelStreamClient(TunnelStreamClient& tunnelStreamClient)
{
	_tunnelStreamClient = &tunnelStreamClient;
}


//Handle refresh messages by forwarding login and source directory refresh messsages to the TunnelStreamClient
void AppClient::onRefreshMsg(const RefreshMsg& refreshMsg, const OmmConsumerEvent& event)
{
	try {
		cout << "AppClient::OnRefreshMsg :: "
			<< refreshMsg << endl;		// defaults to refreshMsg.toString()

		if (_tunnelStreamClient == 0) {
			cout << "No Tunnel Client" << endl;
			return;
		}

		//Forward the Login and Source Directory Refresh messages to the TunnelStreamClient
		switch (refreshMsg.getDomainType())
		{
			case MMT_LOGIN:
				_tunnelStreamClient->processLoginRefresh(refreshMsg, event);
				break;
			case MMT_DIRECTORY:
				_tunnelStreamClient->processSourceDirectoryRefresh(refreshMsg, event);
				break;
			default:
				cout << "Unhandle domain: " << refreshMsg.getDomainType();

		}


	}
	catch (const OmmException& ex)
	{
		cout << ex.toString() << endl;
	}

}

void AppClient::onAckMsg(const AckMsg& ackMsg, const OmmConsumerEvent& event)
{
	cout << endl << "AppClient::onAckMsg :: " << ackMsg << endl;
	
}

//Handle update messages by forwarding source directory update messsages to the TunnelStreamClient
void AppClient::onUpdateMsg(const UpdateMsg& updateMsg, const OmmConsumerEvent& event)
{
	cout << "AppClient::OnUpdateMsg " << updateMsg << endl;		// defaults to updateMsg.toString()
	if (_tunnelStreamClient == 0) {
		cout << "No Tunnel Client" << endl;
		return;
	}

	//Forward the Source Directory Update messages to the TunnelStreamClient

	switch (updateMsg.getDomainType())
	{

	case MMT_DIRECTORY:
		_tunnelStreamClient->processSourceDirectoryUpdate(updateMsg, event);
		break;
	default:
		cout << "Unhandle domain: " << updateMsg.getDomainType();

	}
}

//Handle refresh messages by forwarding login and source directory status messsages to the TunnelStreamClient
void AppClient::onStatusMsg(const StatusMsg& statusMsg, const OmmConsumerEvent& event)
{
	try {
		cout << "AppClient::OnStatusMsg :: " << statusMsg << endl;		// defaults to statusMsg.toString()

		if (_tunnelStreamClient == 0) {
			cout << "No Tunnel Client" << endl;
			return;
		}
		//Forward the Login and Source Directory status messages to the TunnelStreamClient
		switch (statusMsg.getDomainType())
		{
		case MMT_LOGIN:
			_tunnelStreamClient->processLoginStatus(statusMsg, event);
			break;
		case MMT_DIRECTORY:
			_tunnelStreamClient->processSourceDirectoryStatus(statusMsg, event);
			break;
		default:
			cout << "Unhandle domain: " << statusMsg.getDomainType();

		}

		
	}
	catch (const OmmException& ex)
	{
		cout << ex.toString() << endl;
	}
}

void AppClient::onGenericMsg(const GenericMsg& genMsg, const OmmConsumerEvent& ommEvent)
{
	cout << endl << "Received:    GenericMsg" << endl;
	
}

