///*|-----------------------------------------------------------------------------
// *|            This source code is provided under the Apache 2.0 license      --
// *|  and is provided AS IS with no warranty or guarantee of fit for purpose.  --
// *|                See the project's LICENSE.md for details.                  --
// *|           Copyright Refinitiv 2021. All rights reserved.            --
///*|-----------------------------------------------------------------------------

#include "Consumer.h"
#include "AppClient.h"
#include "TunnelStreamClient.h"

using namespace refinitiv::ema::access;
using namespace refinitiv::ema::rdm;
using namespace std;



int main(int argc, char* argv[])
{
	try {

		//Create a AppClient to get the login and source directory messages
		AppClient client;

		//Set RCC service, username, password and post RIC
		const EmaString RCC_SERVICE = "<RCC Service>";
		const EmaString RCC_USERNAME = "<RCC Username>";
		const EmaString RCC_PASSWORD = "<RCC Password>";
		const EmaString RCC_POST_RIC = "<Post Item>";


		//Create a TunnelStreamClient used to manage the tunnel stream including login, and post data
		TunnelStreamClient tunnelClient(RCC_SERVICE, RCC_USERNAME, RCC_PASSWORD, RCC_POST_RIC);
		
		//Set the TunnelStreamClient in the Appclient so the AppClient will forward the login and source directory messages to the TunnelStreamClient
		client.setTunnelStreamClient(tunnelClient);
		
		//Create a OMMConsumer
		OmmConsumer consumer(OmmConsumerConfig().username("rmds"));
		
		//Set the OMMConsumer to the TunnelStreamClient so it can use the OMMConsumer to create a tunnel and submit messages
		tunnelClient.setOmmConsumer(consumer);	

		//Register to get the login and source directory message
		UInt64 loginHandle = consumer.registerClient(ReqMsg().domainType(MMT_LOGIN), client);
		UInt64 directoryHandle = consumer.registerClient(ReqMsg().domainType(MMT_DIRECTORY).serviceName(RCC_SERVICE), client);
		
		while(true)
			sleep(600000);				// API calls onRefreshMsg(), onUpdateMsg(), or onStatusMsg()
	}
	catch (const OmmException& excp) {
		cout << excp << endl;
	}

	return 0;
}
